@@ -10,42 +10,38 @@ use NEXT;
 sub execute {
     my $self = shift;
     my ( $controller, $c ) = @_;
-    
+
     my $config = $controller->_html_formfu_config;
 
     return $self->NEXT::execute(@_)
-      unless exists $self->attributes->{ActionClass}
-      && $self->attributes->{ActionClass}[0] eq $config->{config_action};
+        unless exists $self->attributes->{ActionClass}
+            && $self->attributes->{ActionClass}[0] eq $config->{config_action};
 
-    my $form  = $controller->_form;
+    my $form = $controller->_form;
     my @files = grep {length} split /\s+/, $self->{_attr_params}->[0] || '';
-    
+
     if ( !@files ) {
         push @files, $self->reverse;
     }
-    
+
     my $ext_regex = $config->{_file_ext_regex};
-    
+
     for my $file (@files) {
-        my $filepath = defined $config->{config_file_path}
-            ? $config->{config_file_path} ."/". $file
-            : $file;
-        
-        $c->log->debug( __PACKAGE__ ." loading config file '$filepath'" )
+        $c->log->debug( __PACKAGE__ . " loading config file '$file'" )
             if $c->debug;
-        
+
         if ( $file =~ m/ \. $ext_regex \z /x ) {
-            $form->load_config_file( $filepath );
+            $form->load_config_file($file);
         }
         else {
-            $form->load_config_filestem( $filepath );
+            $form->load_config_filestem($file);
         }
     }
-    
+
     $form->process;
-    
+
     $c->stash->{ $config->{form_stash} } = $form;
-    
+
     $self->NEXT::execute(@_);
 }
 
